joblib.Memory — joblib 0.9.0b4 documentation

# joblib.Memory

class `joblib.` `Memory`(cachedir, mmap_mode=None, compress=False, verbose=1)

  A context object for caching a function’s return value each time it is called with the same input arguments.

  All values are cached on the filesystem, in a deep directory structure.

  see Reference documentation of the Memory class

  `__init__`(cachedir, mmap_mode=None, compress=False, verbose=1)

    Parameters: | cachedir: string or None : The path of the base directory to use as a data store or None. If None is given, no caching is done and the Memory object is completely transparent. mmap_mode: {None, ‘r+’, ‘r’, ‘w+’, ‘c’}, optional : The memmapping mode used when loading from cache numpy arrays. See numpy.load for the meaning of the arguments. compress: boolean, or integer : Whether to zip the stored data on disk. If an integer is given, it should be between 1 and 9, and sets the amount of compression. Note that compressed arrays cannot be read by memmapping. verbose: int, optional : Verbosity flag, controls the debug messages that are issued as functions are evaluated.

  Methods